@@ -216,6 +216,7 @@ __all__ = [
 
 import contextlib
 import os
+import posixpath
 import re
 import shutil
 from typing import Union
@@ -236,6 +237,9 @@ class BaseScreenModel:
     """Implements a base class for model modules."""
 
     _observers = []
+    
+    def __init__(self, database):
+        self.database = database
 
     def add_observer(self, observer) -> None:
         self._observers.append(observer)
@@ -258,11 +262,7 @@ class BaseScreenModel:
                 break
 '''
 
-temp_database_model = '''import multitasking
-
-from Model.base_model import BaseScreenModel
-
-multitasking.set_max_threads(10)
+temp_database_model = '''from Model.base_model import BaseScreenModel
 
 
 class {name_screen}Model(BaseScreenModel):
@@ -272,26 +272,7 @@ class {name_screen}Model(BaseScreenModel):
     """
 
     def __init__(self, database):
-        # Just an example of the data. Use your own values.
-        self._data = None
-
-    @property
-    def data(self):
-        return self._data
-
-    @data.setter
-    def data(self, value):
-        self._data = value
-        # We notify the View -
-        # :class:`~View.{name_screen}.{module_name}.{name_screen}View` about the
-        # changes that have occurred in the data model.
-        self.notify_observers({notify_name_screen})
-
-    @multitasking.task
-    def check_data(self):
-        """Just an example of the method. Use your own code."""
-
-        self.data = ["example item"]
+        super().__init__(database)
 '''
 
 temp_without_database_model = '''from Model.base_model import BaseScreenModel
@@ -334,16 +315,16 @@ class {name_screen}View(MDResponsiveLayout, BaseScreenView):
         """
 '''
 
-temp_responsive_component_imports = """from .platforms.Mobile.mobile_screen import {name_screen}MobileView
-from .platforms.Tablet.tablet_screen import {name_screen}TabletView
-from .platforms.Desktop.desktop_screen import {name_screen}DesktopView
+temp_responsive_component_imports = """from .platforms.Mobile.mobile import {name_screen}MobileView
+from .platforms.Tablet.tablet import {name_screen}TabletView
+from .platforms.Desktop.desktop import {name_screen}DesktopView
 """
 
 temp_responsive_platform_baseclass = """from kivymd.uix.screen import MDScreen
 from kivy.lang import Builder
 from os.path import dirname, join, basename
 
-Builder.load_file(join(dirname(__file__), basename(__file__).replace(".py", ".kv")))
+Builder.load_file(join(dirname(__file__), basename(__file__).split(".")[0] + ".kv"))
 
 
 class {}View(MDScreen):
@@ -362,10 +343,10 @@ class {name_screen}View(BaseScreenView):
         """
 '''
 
-temp_code_controller = '''{import_module}
+temp_code_controller = '''from Controller.base_controller import BaseScreenController
 
 
-class {name_screen}Controller:
+class {name_screen}Controller(BaseScreenController):
     """
     The `{name_screen}Controller` class represents a controller implementation.
     Coordinates work of the view with the model.
@@ -373,19 +354,10 @@ class {name_screen}Controller:
     the view to control its actions.
     """
 
-    def __init__(self, model):
-        self.model = model  # Model.{module_name}.{name_screen}Model
-        self.view = {name_view}(controller=self, model=self.model)
-
-    def get_view(self) -> {get_view}:
-        return self.view
 '''
 
 temp_base_screen = '''from kivy.properties import ObjectProperty
-
-from kivymd.app import MDApp
 from kivymd.uix.screen import MDScreen
-
 from Utility.observer import Observer
 
 
@@ -411,19 +383,11 @@ class BaseScreenView(MDScreen, Observer):
     and defaults to `None`.
     """
 
-    manager_screens = ObjectProperty()
-    """
-    Screen manager object - :class:`~kivymd.uix.screenmanager.MDScreenManager`.
-
-    :attr:`manager_screens` is an :class:`~kivy.properties.ObjectProperty`
-    and defaults to `None`.
-    """
-
-    def __init__(self, **kw):
+    def __init__(self, app, **kw):
         super().__init__(**kw)
         # Often you need to get access to the application object from the view
         # class. You can do this using this attribute.
-        self.app = MDApp.get_running_app()
+        self.app = app
         # Adding a view class as observer.
         self.model.add_observer(self)
 '''
@@ -502,7 +466,6 @@ class {}(MDApp):
             model = screens[name_screen]["model"]({})
             controller = screens[name_screen]["controller"](model)
             view = controller.get_view()
-            view.manager_screens = self.manager_screens
             view.name = name_screen
             self.manager_screens.add_widget(view)
 
@@ -526,6 +489,19 @@ class {}(MDApp):
 # code to test the application normally without hot reloading.
 '''
 
+temp_base_controller = """class BaseScreenController:
+    def __init__(self, app, model):
+        self.app = app
+        self.model = model
+        self.view = None
+        
+    def set_view(self, view):
+        self.view = view
+        
+    def get_view(self):
+        return self.view
+"""
+
 temp_main = '''"""
 The entry point to the application.
 
@@ -588,9 +564,9 @@ class {}(MDApp):{}
     def load_screen(self, name_screen, switch, first):
         Builder.load_file(screens[name_screen]["kv"])
         model = screens[name_screen]["model"]({})
-        controller = screens[name_screen]["controller"](model)
-
-        view = controller.get_view()
+        controller = screens[name_screen]["controller"](self, model)
+        view = screens[name_screen]["view"](self, model=model, controller=controller)
+        controller.set_view(view)
         self.root.add_widget(view)
         if switch:
             self.root.current = name_screen
@@ -723,7 +699,7 @@ def main():
         create_main()
 
         for name in name_screen:
-            module_name = chek_camel_case_name_project(name)
+            module_name = check_camel_case_name_project(name)
             if not module_name:
                 parser.error(
                     "The name of the screen should be written in camel case style. "
@@ -945,27 +921,14 @@ def create_controller(
         if use_hotreload == "yes"
         else f"{name_screen}View"
     )
-    code_controller = temp_code_controller.format(
-        name_screen=name_screen,
-        module_name=module_name,
-        import_module=""
-                      f"import importlib\n\n"
-                      f"import View.{name_screen}.{module_name}\n\n"
-                      f"# We have to manually reload the view module in order to apply the\n"
-                      f"# changes made to the code on a subsequent hot reload.\n"
-                      f"# If you no longer need a hot reload, you can delete this instruction.\n"
-                      f"importlib.reload(View.{name_screen}.{module_name})\n\n"
-        if use_hotreload == "yes"
-        else f"\nfrom View.{name_screen}.{module_name} import {name_screen}View",
-        name_view=name_view,
-        get_view=f"View.{name_screen}.{module_name}"
-        if use_hotreload == "yes"
-        else f"{name_screen}View",
-    )
+    code_controller = temp_code_controller.format(name_screen=name_screen)
 
     path_to_controller = os.path.join(path_to_project, "Controller")
+    path_to_base_controller = os.path.join(path_to_controller, "base_controller.py")
     if not os.path.exists(path_to_controller):
         os.mkdir(path_to_controller)
+        with open(path_to_base_controller, "w", encoding="utf-8") as base:
+            base.write(temp_base_controller)
     controller_module = os.path.join(path_to_project, "Controller", module_name)
     with open(f"{controller_module}.py", "w", encoding="utf-8") as module:
         module.write(code_controller)
@@ -997,15 +960,21 @@ def create_screens_data(name_screen: str, module_name: str) -> None:
     temp_screens_imports += (
         f"from Model.{module_name} import {name_screen}Model\n"
         f"from Controller.{module_name} import {name_screen}Controller\n"
+        f"from View.{name_screen}.{module_name} import {name_screen}View\n"
     )
     temp_screens_data += (
-        '\n    %s: {\n        "model": %s,'
-        '\n        "controller": %s,\n        "kv": %s},\n'
+        '\n    %s: {'
+        '\n        "model": %s,'
+        '\n        "controller": %s,'
+        '\n        "view": %s,'
+        '\n        "kv": %s'
+        '\n    },\n'
         % (
             f'"{" ".join(module_name.split("_"))}"',
             f"{name_screen}Model",
             f"{name_screen}Controller",
-            f"{os.path.join(path_to_project, 'View', f'{module_name}.kv')}",
+            f"{name_screen}View",
+            f"\"{posixpath.join('./View', name_screen, f'{module_name}.kv')}\"",
         )
     )
 
@@ -1014,7 +983,7 @@ def create_module_screens() -> None:
     path_to_module_screens = os.path.join(path_to_project, "View", "screens.py")
     with open(path_to_module_screens, "w", encoding="utf-8") as module_screens:
         module_screens.write(
-            "%s\nscreens = {%s}" % (temp_screens_imports, temp_screens_data)
+            "%s\nscreens = {%s}\n" % (temp_screens_imports, temp_screens_data)
         )
 
 
@@ -1040,7 +1009,7 @@ def create_view(
         name_screen: str,
         module_name: str,
         use_responsive: list,
-        path_to_project: str,
+        path_to_project: str
 ) -> None:
     path_to_view = os.path.join(path_to_project, "View", name_screen)
     path_to_components = os.path.join(path_to_view, "components")
@@ -1199,8 +1168,8 @@ def check_databases() -> None:
     )
 
 
-def chek_camel_case_name_project(name_project) -> Union[bool, list]:
-    result = re.findall("[A-Z][a-z]*", name_project)
+def check_camel_case_name_project(name_project) -> Union[bool, list]:
+    result = re.findall(r"[A-Z][^A-Z]*", name_project)
     return False if len(result) == 1 else result
 
 
